﻿// Copyright (c) Strange Loop Games. All rights reserved.
// See LICENSE file in the project root for full license information.
// <auto-generated />

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Core.Items;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.World;
    using Eco.World.Blocks;
    using Eco.Gameplay.Pipes;
    using Eco.Shared.Math;
  
    [RepairRequiresSkill(typeof(AdvancedSmeltingSkill), 2)] 
    public partial class ModernAxeRecipe :
        RecipeFamily
    {
        public ModernAxeRecipe()
        {
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "ModernAxe",
                    Localizer.DoStr("Modern Axe"),
                    new IngredientElement[]
                    {
               new IngredientElement(typeof(ModernAxeHeadItem), 1, true),
               new IngredientElement(typeof(ModernHandleItem), 1, true),
                    },
                new CraftingElement<ModernAxeItem>()
                )
            };
            this.LaborInCalories = CreateLaborInCaloriesValue(250); 
            this.CraftMinutes = CreateCraftTimeValue(0.5f);    
            this.Initialize(Localizer.DoStr("Modern Axe"), typeof(ModernAxeRecipe));
            CraftingComponent.AddRecipe(typeof(ToolBenchObject), this);
        }
    }

    [Serialized]
    [LocDisplayName("Modern Axe")]
    [Tier(4)] 
    [Weight(1000)]
    [Category("Tool")]
    [Tag("Tool", 1)]
    [Ecopedia("Items", "Tools", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]                    
    public partial class ModernAxeItem : AxeItem
    {
        // Static values
        private static IDynamicValue caloriesBurn = new MultiDynamicValue(MultiDynamicOps.Multiply, new TalentModifiedValue(typeof(ModernAxeItem), typeof(LoggingToolEfficiencyTalent)), CreateCalorieValue(10, typeof(LoggingSkill), typeof(ModernAxeItem)));
        private static IDynamicValue damage = CreateDamageValue(2.5f, typeof(LoggingSkill), typeof(ModernAxeItem)); 
        private static IDynamicValue exp = new ConstantValue(0.1f);
        private static IDynamicValue tier = new MultiDynamicValue(MultiDynamicOps.Sum, new ConstantValue(4), new TalentModifiedValue(typeof(ModernAxeItem), typeof(LoggingToolStrengthTalent), 0));
        private static IDynamicValue skilledRepairCost = new ConstantValue(1);


        // Tool overrides

        public override IDynamicValue CaloriesBurn      => caloriesBurn;
        public override IDynamicValue Damage            => damage; 
        public override Type ExperienceSkill            => typeof(LoggingSkill);
        public override IDynamicValue ExperienceRate    => exp;
        public override IDynamicValue Tier              => tier;
        public override IDynamicValue SkilledRepairCost => skilledRepairCost;
        public override float DurabilityRate            => DurabilityMax / 2500f;
        public override Item RepairItem => RandomUtil.CoinToss() ? Get<ModernAxeHeadItem>() : Get<ModernHandleItem>();
        public override int FullRepairAmount => 1;
    }
}
