﻿// Copyright (c) Strange Loop Games. All rights reserved.
// See LICENSE file in the project root for full license information.
// <auto-generated />

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Core.Items;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.World;
    using Eco.World.Blocks;
    using Eco.Gameplay.Pipes;
    using Eco.Shared.Math;
 
    [RepairRequiresSkill(typeof(AdvancedSmeltingSkill), 2)] 
    public partial class SteelPickaxeRecipe :
        RecipeFamily
    {
        public SteelPickaxeRecipe()
        {
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "SteelPickaxe",
                    Localizer.DoStr("Steel Pickaxe"),
                    new IngredientElement[]
                    {
               new IngredientElement(typeof(SteelPickaxeHeadItem), 1, true),
               new IngredientElement(typeof(ModernWoodHandleItem), 1, true),
                    },
                new CraftingElement<SteelPickaxeItem>()
                )
            };
            this.LaborInCalories = CreateLaborInCaloriesValue(250); 
            this.CraftMinutes = CreateCraftTimeValue(0.5f);    
            this.Initialize(Localizer.DoStr("Steel Pickaxe"), typeof(SteelPickaxeRecipe));
            CraftingComponent.AddRecipe(typeof(ToolBenchObject), this);
        }
    }

    [Serialized]
    [LocDisplayName("Steel Pickaxe")]
    [Tier(3)] 
    [Weight(1000)]
    [Category("Tool")]
    [Tag("Tool", 1)]
    [Ecopedia("Items", "Tools", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]                    
    public partial class SteelPickaxeItem : PickaxeItem
    {
        // Static values
        private static IDynamicValue caloriesBurn = new MultiDynamicValue(MultiDynamicOps.Multiply, new TalentModifiedValue(typeof(SteelPickaxeItem), typeof(MiningToolEfficiencyTalent)), CreateCalorieValue(15, typeof(MiningSkill), typeof(SteelPickaxeItem)));
        private static IDynamicValue exp = new ConstantValue(0.1f);
        private static IDynamicValue tier = new MultiDynamicValue(MultiDynamicOps.Sum, new ConstantValue(3), new TalentModifiedValue(typeof(SteelPickaxeItem), typeof(MiningToolStrengthTalent), 0));
        private static IDynamicValue skilledRepairCost = new ConstantValue(1);


        // Tool overrides

        public override IDynamicValue CaloriesBurn      => caloriesBurn;
        public override float Damage                    => 1.2f; 
        public override Type ExperienceSkill            => typeof(MiningSkill);
        public override IDynamicValue ExperienceRate    => exp;
        public override IDynamicValue Tier              => tier;
        public override IDynamicValue SkilledRepairCost => skilledRepairCost;
        public override float DurabilityRate            => DurabilityMax / 1000f;
        public override Item RepairItem => RandomUtil.CoinToss() ? Get<SteelPickaxeHeadItem>() : Get<ModernWoodHandleItem>();
        public override int FullRepairAmount => 1;
    }
}
