﻿// Copyright (c) Strange Loop Games. All rights reserved.
// See LICENSE file in the project root for full license information.
// <auto-generated />

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Core.Items;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.World;
    using Eco.World.Blocks;
    using Eco.Gameplay.Pipes;
    using Eco.Shared.Math;

    [RepairRequiresSkill(typeof(BasicEngineeringSkill), 2)] 
    public partial class SteelRoadToolRecipe :
        RecipeFamily
    {
        public SteelRoadToolRecipe()
        {
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "SteelRoadTool",
                    Localizer.DoStr("Steel Road Tool"),
                    new IngredientElement[]
                    {
               new IngredientElement(typeof(SteelRoadToolHeadItem), 1, true),
               new IngredientElement(typeof(ModernWoodHandleItem), 1, true),
                    },
                new CraftingElement<SteelRoadToolItem>()
                )
            };
            this.LaborInCalories = CreateLaborInCaloriesValue(25); 
            this.CraftMinutes = CreateCraftTimeValue(0.5f);    
            this.Initialize(Localizer.DoStr("Steel Road Tool"), typeof(SteelRoadToolRecipe));
            CraftingComponent.AddRecipe(typeof(ToolBenchObject), this);
        }
    }

    [Serialized]
    [LocDisplayName("Steel Road Tool")]
    [Tier(3)] 
    [Weight(1000)]
    [Category("Tool")]
    [Tag("Tool", 1)]
    [Ecopedia("Items", "Tools", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]                    
    public partial class SteelRoadToolItem : RoadToolItem
    {
        // Static values
        private static IDynamicValue caloriesBurn = new MultiDynamicValue(MultiDynamicOps.Multiply, new TalentModifiedValue(typeof(SteelRoadToolItem), typeof(ToolEfficiencyTalent)), CreateCalorieValue(15, typeof(BasicEngineeringSkill), typeof(SteelRoadToolItem)));
        private static IDynamicValue exp = new ConstantValue(0.1f);
        private static IDynamicValue tier = new ConstantValue(3);
        private static IDynamicValue skilledRepairCost = new ConstantValue(1);


        // Tool overrides

        public override LocString DisplayDescription    => Localizer.DoStr("A tool for tamping dirt into roads.");    
        public override IDynamicValue CaloriesBurn      => caloriesBurn;
        public override Type ExperienceSkill            => typeof(BasicEngineeringSkill);
        public override IDynamicValue ExperienceRate    => exp;
        public override IDynamicValue Tier              => tier;
        public override IDynamicValue SkilledRepairCost => skilledRepairCost;
        public override float DurabilityRate            => DurabilityMax / 1000f;
        public override Item RepairItem => RandomUtil.CoinToss() ? Get<SteelRoadToolHeadItem>() : Get<ModernWoodHandleItem>();
        public override int FullRepairAmount => 1;
    }
}
