﻿// Copyright (c) Strange Loop Games. All rights reserved.
// See LICENSE file in the project root for full license information.
// <auto-generated />

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Core.Items;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.World;
    using Eco.World.Blocks;
    using Eco.Gameplay.Pipes;
    using Eco.Shared.Math;

    [RepairRequiresSkill(typeof(BasicEngineeringSkill), 1)] 
    public partial class StoneRoadToolRecipe :
        RecipeFamily
    {
        public StoneRoadToolRecipe()
        {
            this.Recipes = new List<Recipe>
            {
                new Recipe(
                    "StoneRoadTool",
                    Localizer.DoStr("Stone Road Tool"),
                    new IngredientElement[]
                    {
               new IngredientElement(typeof(StoneRoadToolHeadItem), 1, true),
               new IngredientElement(typeof(PrimitiveWoodHandleItem), 1, true),
                    },
                new CraftingElement<StoneRoadToolItem>()
                )
            };
            this.LaborInCalories = CreateLaborInCaloriesValue(10); 
            this.CraftMinutes = CreateCraftTimeValue(0.5f);    
            this.Initialize(Localizer.DoStr("Stone Road Tool"), typeof(StoneRoadToolRecipe));
            CraftingComponent.AddRecipe(typeof(ToolBenchObject), this);
        }
    }

    [Serialized]
    [LocDisplayName("Stone Road Tool")]
    [Tier(1)] 
    [Weight(1000)]
    [Category("Tool")]
    [Tag("Tool", 1)]
    [Ecopedia("Items", "Tools", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]                    
    public partial class StoneRoadToolItem : RoadToolItem
    {
        // Static values
        private static IDynamicValue caloriesBurn = new MultiDynamicValue(MultiDynamicOps.Multiply, new TalentModifiedValue(typeof(StoneRoadToolItem), typeof(ToolEfficiencyTalent)), CreateCalorieValue(20, typeof(BasicEngineeringSkill), typeof(StoneRoadToolItem)));
        private static IDynamicValue exp = new ConstantValue(0.1f);
        private static IDynamicValue tier = new ConstantValue(1);
        private static SkillModifiedValue skilledRepairCost = new SkillModifiedValue(5, BasicEngineeringSkill.MultiplicativeStrategy, typeof(BasicEngineeringSkill), Localizer.DoStr("repair cost"), DynamicValueType.Efficiency); 
        

        // Tool overrides

        public override LocString DisplayDescription    => Localizer.DoStr("A tool for tamping dirt into roads.");    
        public override IDynamicValue CaloriesBurn      => caloriesBurn;
        public override Type ExperienceSkill            => typeof(BasicEngineeringSkill);
        public override IDynamicValue ExperienceRate    => exp;
        public override IDynamicValue Tier              => tier;
        public override IDynamicValue SkilledRepairCost => skilledRepairCost;
        public override float DurabilityRate            => DurabilityMax / 100f;
        public override Item RepairItem => RandomUtil.CoinToss() ? Get<StoneRoadToolHeadItem>() : Get<PrimitiveWoodHandleItem>();
        public override int FullRepairAmount => 1;
    }
}
